local colorsfile = vim.fn.stdpath("state") .. "/colorscheme.lua"
local function source_colors()
	if vim.fn.filereadable(colorsfile) == 1 then
		vim.cmd("source " .. colorsfile)
	end
end
-- set on startup
source_colors()

-- continuously watch colors file for changes
local fwatch = require("fwatch")
fwatch.watch(colorsfile, {
	on_event = vim.schedule_wrap(function()
		source_colors()
	end),
})

require("mini.ai").setup()
require("mini.comment").setup({
	hooks = {
		pre = function()
			require("ts_context_commentstring.internal").update_commentstring()
		end,
	},
})
require("mini.cursorword").setup({ delay = 500 })
require("mini.fuzzy").setup()

require("mini.indentscope").setup({
	symbol = "│",
	draw = { animation = require("mini.indentscope").gen_animation.none() },
	options = { indent_at_cursor = false },
})

require("mini.map").setup()
require("mini.move").setup() -- has not hit stable yet
require("mini.pairs").setup()
require("mini.trailspace").setup()

local starter = require("mini.starter")
starter.setup({
	evaluate_single = true,
	items = {
		starter.sections.builtin_actions(),
		starter.sections.recent_files(10, false),
		starter.sections.recent_files(10, true),
		-- Use this if you set up 'mini.sessions'
		starter.sections.telescope(),
	},
	content_hooks = {
		starter.gen_hook.adding_bullet(),
		starter.gen_hook.padding(3, 2),
		starter.gen_hook.aligning("center", "center"),
	},
})

vim.api.nvim_set_hl(0, "MiniCursorword", { bold = true })

require("mini.bracketed").setup({
	{
		buffer = { suffix = "b", options = {} },
		comment = { suffix = "c", options = {} },
		conflict = { suffix = "", options = {} },
		diagnostic = { suffix = "d", options = {} },
		file = { suffix = "f", options = {} },
		indent = { suffix = "", options = {} }, -- disable since we use indentscope above
		jump = { suffix = "j", options = {} },
		location = { suffix = "l", options = {} },
		oldfile = { suffix = "o", options = {} },
		quickfix = { suffix = "q", options = {} },
		treesitter = { suffix = "t", options = {} },
		undo = { suffix = "", options = {} }, -- disable since I don't need it
		window = { suffix = "w", options = {} },
		yank = { suffix = "y", options = {} },
	},
})
