return {
	{
		"quarto-dev/quarto-nvim",
		dependencies = {
			"jmbuhr/otter.nvim",
			"neovim/nvim-lspconfig",
			"vim-pandoc/vim-pandoc-syntax",
			"hrsh7th/nvim-cmp",
			"nvim-treesitter/nvim-treesitter",
		},
		config = function()
			require("quarto").setup({
				lspFeatures = {
					enabled = true,
					languages = { "r", "python", "julia", "bash" },
					diagnostics = { enabled = false, triggers = { "BufWritePost" } },
					completion = { enabled = true },
				},
				codeRunner = {
					enabled = true,
					default_method = "molten",
				},
			})
		end,
		ft = { "quarto" },
	},

	-- REPL work
	{
		"3rd/image.nvim",
		config = function()
			-- Example for configuring Neovim to load user-installed installed Lua rocks:
			package.path = package.path .. ";" .. vim.fn.expand("$HOME") .. "/.luarocks/share/lua/5.1/?/init.lua;"
			package.path = package.path .. ";" .. vim.fn.expand("$HOME") .. "/.luarocks/share/lua/5.1/?.lua;"
			require("image").setup({
				backend = "kitty",
				integrations = {
					markdown = {
						enabled = true,
						download_remote_images = true,
						only_render_image_at_cursor = true,
						filetypes = { "markdown", "vimwiki", "quarto" },
					},
				},
			})
		end,
		ft = { "markdown", "vimwiki", "quarto" },
	},
	{
		"benlubas/molten-nvim",
		build = ":UpdateRemotePlugins",
		config = function()
			vim.g.molten_image_provider = "none" -- image integration does NOT work currently :-(
			vim.g.molten_auto_open_output = false
		end,
		cmd = {
			"MoltenInfo",
			"MoltenInit",
			"MoltenDeinit",
			"MoltenGoto",
			"MoltenNext",
			"MoltenPrev",
			"MoltenEvaluateLine",
			"MoltenEvaluateVisual",
			"MoltenEvaluateOperator",
			"MoltenEvaluateArgument",
			"MoltenReevaluateCell",
			"MoltenDelete",
			"MoltenShowOutput",
			"MoltenHideOutput",
			"MoltenEnterOutput",
			"MoltenInterrupt",
			"MoltenRestart",
			"MoltenSave",
			"MoltenLoad",
			"MoltenExportOutput",
		},
		ft = { "quarto", "python" },
		lazy = false,
		keys = {
			{ "<leader>vn", ":MoltenInfo<cr>" },
		},
	},

	-- MARKDOWN ONLY
	-- Evaluate markdown code blocks
	{
		"jubnzv/mdeval.nvim",
		cmd = {
			"MdEval",
		},
		ft = { "markdown" },
		opts = {
			require_confirmation = false,
			eval_options = {},
		},
		lazy = false,
	},
	{
		"AckslD/nvim-FeMaco.lua",
		cmd = {
			"FeMaco",
		},
		ft = { "markdown" },
		config = true,
	},
}
