return {
	-- statusline
	{
		"nvim-lualine/lualine.nvim",
		requires = { "nvim-tree/nvim-web-devicons", config = true },
		opts = {
			options = {
				icons_enabled = true,
				theme = "auto",
				component_separators = { left = "", right = "" },
				section_separators = { left = "", right = "" },
				disabled_filetypes = {},
				always_divide_middle = true,
			},
			sections = {
				lualine_a = { "mode" },
				lualine_b = { "branch", "diff", "diagnostics" },
				lualine_c = { "filename" },
				lualine_x = { "encoding", "fileformat", "filetype" },
				lualine_y = { "progress", "location" },
				lualine_z = { "hostname" },
			},
			inactive_sections = {
				lualine_a = {},
				lualine_b = { "branch", "diff" },
				lualine_c = { "filename" },
				lualine_x = {},
				lualine_y = { "location" },
				lualine_z = {},
			},
			tabline = {},
			extensions = { "quickfix", "toggleterm" },
		},
		event = { "BufNewFile", "BufAdd", "BufWinEnter" },
	},
	-- create pretty unobtrusive notifications
	{
		"j-hui/fidget.nvim",
		opts = {
			progress = {
				suppress_on_insert = true,
				ignore_done_already = true,
			},
			notification = {
				override_vim_notify = true,
			},
		},
		event = "VimEnter",
	},
	-- make all vim.ui interfaces prettyy
	{ "stevearc/dressing.nvim", config = true, event = "VeryLazy" },

	-- numbers to absolute for all buffers but the current which is relative
	{ "jeffkreeftmeijer/vim-numbertoggle", event = "BufEnter" },
	-- auto-hiding colorcolumn
	{
		"m4xshen/smartcolumn.nvim",
		event = "BufEnter",
		opts = {
			colorcolumn = { "100" },
			scope = "window",
			disabled_filetypes = {
				"help",
				"text",
				"markdown",
				"NvimTree",
				"lazy",
				"mason",
				"help",
				"quarto",
			},
		},
	},
	-- display pretty colors when they are mentioned in buffer
	{
		"NvChad/nvim-colorizer.lua", -- color hex, named colors in the correct preview scheme
		config = function()
			require("colorizer").setup({
				user_default_options = { mode = "virtualtext" },
			})
		end,
		cmd = {
			"ColorizerToggle",
			"ColorizerAttachToBuffer",
			"ColorizerDetachFromBuffer",
			"ColorizerReloadAllBuffers",
		},
		keys = {
			{ "<localleader>sc", "<cmd>ColorizerToggle<cr>", { silent = true, desc = "toggle colorizer" } },
			{
				"<localleader>sC",
				'<cmd>lua require("colorizer").attach_to_buffer(0, {mode = "background"} )<cr>',
				{ silent = true, desc = "colorize background" },
			},
		},
	},
	{
		"jiaoshijie/undotree",
		dependencies = {
			"nvim-lua/plenary.nvim",
		},
		config = true,
		keys = {
			{
				"<leader>su",
				function()
					require("undotree").toggle()
				end,
				desc = "toggle undotree",
				silent = true,
			},
		},
	},
}
